@@ -1,5 +1,5 @@
 package Apache::AxKit::Plugin::AddXSLParams::BasicSession;
-# $Id: BasicSession.pm,v 1.4 2004/08/19 22:31:22 nachbaur Exp $
+# $Id: BasicSession.pm,v 1.5 2004/09/17 02:05:22 kjetil Exp $
 
 use strict;
 use Apache::Constants;
@@ -7,7 +7,7 @@ use Apache::Cookie;
 use Apache::Request;
 use Apache::URI;
 use vars qw($VERSION);
-$VERSION = '0.19';
+$VERSION = '0.20';
 
 
 sub handler {
@@ -16,6 +16,7 @@ sub handler {
     my $cgi = Apache::Request->instance($r);
      
     return OK unless ($Apache::AxKit::Plugin::BasicSession::session{_session_id});
+    $cgi->parms->set('session.id' => $Apache::AxKit::Plugin::BasicSession::session{_session_id});
     my $session = \%Apache::AxKit::Plugin::BasicSession::session;
     foreach my $sesskey ( keys( %{$session} ) ) {
         next if ($sesskey =~ /^_/);
@@ -40,28 +41,35 @@ Apache::AxKit::Plugin::AddXSLParams::BasicSession - Provides a way to pass info
 
 =head1 DESCRIPTION
 
-Apache::AxKit::Plugin::AddXSLParams::BasicSession (Whew! that's a mouthful) offers a way to
-make information about the current session available as params within XSLT stylesheets.  This
-module, as well as parts of the documentation, were blatantly ripped off from
+Apache::AxKit::Plugin::AddXSLParams::BasicSession (Whew! that's a
+mouthful) offers a way to make information about the current session
+available as params within XSLT stylesheets.  This module, as well as
+parts of the documentation, were blatantly ripped off from
 Apache::AxKit::Plugin::AddXSLParams::Request.  Thanks!
 
 =head1 CONFIGURATION
 
-There is no configuration for this module, seeing as all session configuration needs to occur
-for the Apache::AxKit::Plugin::BasicSession module.
+There is no configuration for this module, seeing as all session
+configuration needs to occur for the
+Apache::AxKit::Plugin::BasicSession module.
 
 =head1 USAGE
 
-Like A:A:P:A:Request, you can access session key values by defining a specially named XSL
-parameter.  A:A:P:A:BasicSession uses the prefix "session.keys" to represent key values.
-For instance, if you have a session key named "search-max", the following would work:
+Like A:A:P:A:Request, you can access session key values by defining a
+specially named XSL parameter.  A:A:P:A:BasicSession uses the prefix
+"session.keys" to represent key values.  For instance, if you have a
+session key named "search-max", the following would work:
 
   <xsl:param name="session.keys.search-max"/>
   ...
   <xsl:value-of select="$session.keys.search-max"/>
 
-Any key that begins with an underscore ("_") will not be passed as an XSL parameter, since
-these are considered "hidden" keys managed by the BasicSession package.
+Any key that begins with an underscore ("_") will not be passed as an
+XSL parameter, since these are considered "hidden" keys managed by the
+BasicSession package.
+
+In addition to the session keys, you can also get the session ID
+string using C<session.id>.
 
 =head1 DEPENDENCIES
 
@@ -76,12 +84,13 @@ these are considered "hidden" keys managed by the BasicSession package.
 =head1 AUTHOR
 
 Michael A Nachbaur, mike@nachbaur.com
+Kjetil Kjernsmo, kjetilk@cpan.org
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2003 Michael A Nachbaur. All rights reserved. This program is
-free software; you can redistribute it and/or modify it under the same
-terms as Perl itself.
+Copyright (c) 2001-2004 Michael A Nachbaur, Kjetil Kjernsmo 2004. All
+rights reserved. This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
